mailr13979 - /branches/gui_testing/gui/relax_gui.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on July 29, 2011 - 09:12:
Author: bugman
Date: Fri Jul 29 09:12:28 2011
New Revision: 13979

URL: http://svn.gna.org/viewcvs/relax?rev=13979&view=rev
Log:
The GUI is now frozen while opening a relax state, and then finally thawed.

This removes visual artifacts on Mac OS X.


Modified:
    branches/gui_testing/gui/relax_gui.py

Modified: branches/gui_testing/gui/relax_gui.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/gui_testing/gui/relax_gui.py?rev=13979&r1=13978&r2=13979&view=diff
==============================================================================
--- branches/gui_testing/gui/relax_gui.py (original)
+++ branches/gui_testing/gui/relax_gui.py Fri Jul 29 09:12:28 2011
@@ -443,8 +443,9 @@
         # Yield to allow the cursor to be changed.
         wx.Yield()
 
         # Change the cursor to waiting.
         wx.BeginBusyCursor()
+        self.Freeze()
 
         # Delete the current tabs.
         self.analysis.delete_all()
@@ -464,7 +465,8 @@
         # Update the core of the GUI to match the new data store.
         self.sync_ds(upload=False)
 
-        # Reset the cursor.
+        # Reset the cursor, and thaw the GUI.
+        self.Thaw()
         wx.EndBusyCursor()
 
 
@@ -443,8 +443,9 @@
         wx.Yield()
 
-        # Change the cursor to waiting.
+        # Change the cursor to waiting, and freeze the GUI.
         wx.BeginBusyCursor()




Related Messages


Powered by MHonArc, Updated Fri Jul 29 09:20:03 2011